@@ -1,5 +1,5 @@
 package App::GitGot::Command::fork;
-$App::GitGot::Command::fork::VERSION = '1.25';
+$App::GitGot::Command::fork::VERSION = '1.30';
 # ABSTRACT: fork a github repo
 use 5.014;
 
@@ -19,7 +19,8 @@ use namespace::autoclean;
 sub options {
   my( $class , $app ) = @_;
   return (
-    [ 'noclone|n' => 'FIXME' ] ,
+    [ 'noclone|n'     => 'If set, do not check out a local working copy of the forked repo' ] ,
+    [ 'noremoteadd|N' => 'If set, do not add the forked repo as the "upstream" repo in the new working copy' ] ,
   );
 }
 
@@ -37,17 +38,29 @@ sub _execute {
 
   my %gh_args = _parse_github_identity();
 
+  say "Forking '$owner/$repo_name'..." unless $self->quiet;
+
   my $resp = Net::GitHub->new( %gh_args )->repos->create_fork( $owner , $repo_name );
 
+  my $path = cwd() . "/$repo_name";
+
   my $new_repo = App::GitGot::Repo::Git->new({ entry => {
     name => $repo_name ,
-    path => cwd() . "/$repo_name" ,
+    path => $path ,
     repo => $resp->{ssh_url} ,
     type => 'git' ,
   }});
 
-  $new_repo->clone( $resp->{ssh_url} )
-    unless $self->opt->noclone;
+  if ( ! $self->opt->noclone ) {
+    say "Cloning into $path" unless $self->quiet;
+    $new_repo->clone( $resp->{ssh_url} );
+
+    if ( ! $self->opt->noremoteadd ) {
+      say "Adding '$github_url' as remote 'upstream'..."
+        unless $self->quiet;
+      $new_repo->remote( add => upstream => $github_url );
+    }
+  }
 
   $self->add_repo( $new_repo );
   $self->write_config;
@@ -84,16 +97,15 @@ sub _parse_github_identity {
 sub _parse_github_url {
   my $url = shift;
 
-  my( $owner , $repo ) = $url =~ m|/github.com/([^/]+)/([^/]+).git$|
-    or say STDERR "ERROR: Can't parse '$url'" and exit(1);
+  my( $owner , $repo ) = $url =~ m|/github.com/([^/]+)/([^/]+?)(?:\.git)?$|
+    or say STDERR "ERROR: Can't parse '$url'.\nURL needs to be of the form 'github.com/OWNER/REPO'.\n"
+    and exit(1);
 
   return( $owner , $repo );
 }
 
 1;
 
-## FIXME docs
-
 __END__
 
 =pod
@@ -106,7 +118,16 @@ App::GitGot::Command::fork - fork a github repo
 
 =head1 VERSION
 
-version 1.25
+version 1.30
+
+=head1 SYNOPSIS
+
+    # fork repo on GitHub, then clone repository and add to got config
+    $ got fork github.com/owner/repo
+
+    # fork repo on GitHub, add to got config, but do _not_ clone locally
+    $ got fork -n github.com/owner/repo
+    $ got fork --noclone github.com/owner/repo
 
 =head1 AUTHOR
 
