@@ -5,19 +5,22 @@ use 5.014;                      # strict, unicode_strings
 use warnings;
 
 use Carp;
+use File::Temp         qw/ tempdir tempfile /;
 use Path::Tiny;
 use YAML               qw/ DumpFile /;
 
 INIT {
-  my $config = Path::Tiny->tempfile();
+  my $config = tempfile(UNLINK => 1);
   $ENV{GIT_CONFIG} = $config;
   Test::Class->runtests;
 }
 
 sub build_fake_git_repo {
   my $repo = shift || 'foo.git';
-  `mkdir $repo && cd $repo && git init && touch foo && git add foo && git commit -m"mu"`;
-  `cd $repo && touch bar && git add bar && git commit -m"mu2"`;
+  `mkdir $repo && cd $repo && git init && git config user.name "Boo" && git config user.email "radley\@example.com"`;
+  foreach my $x ( qw/ foo bar / ) {
+    `cd $repo && touch $x && git add $x && git commit -m"$x"`;
+  }
   chdir $repo;
 }
 
@@ -29,7 +32,7 @@ EOF
 }
 
 sub create_tempdir_and_chdir {
-  my $dir = Path::Tiny->tempdir(CLEANUP=>1);
+  my $dir = tempdir(CLEANUP=>1);
   chdir $dir;
   return $dir;
 }
@@ -64,7 +67,7 @@ sub write_fake_config {
   build_fake_git_repo( 'bar.git' );
   chdir('..');
 
-  my $name = Path::Tiny->tempfile();
+  my( undef , $name ) = tempfile(UNLINK=>1);
   DumpFile( $name , $config );
 
   return( $name , $dir );
